@@ -24,6 +24,7 @@
 #include <string.h>
 #include <stdlib.h>
 
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
 #include <panel-applet.h>
@@ -147,7 +148,6 @@ static const SeahorsePGPHeader seahorse_pgp_headers[] = {
 
 typedef struct _SeahorseAppletPrivate {
     GtkWidget           *image;
-    GtkTooltips         *tooltips;
     GtkClipboard        *board;
     GtkWidget           *menu;
     SeahorseTextType    clipboard_contents;
@@ -666,6 +666,18 @@ dvi_cb (GtkMenuItem *menuitem, SeahorseApplet *sapplet)
             (GtkClipboardTextReceivedFunc)dvi_received, sapplet);
 }
 
+static void
+close_props (GtkButton *button, SeahorseWidget *swidget)
+{
+    seahorse_widget_destroy (swidget);
+}
+
+static void
+win_destroyed (GtkWidget *widget, GdkEvent *event, SeahorseWidget *swidget)
+{
+    seahorse_widget_destroy (swidget);
+}
+
 void
 properties_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verbname)
 {
@@ -675,7 +687,7 @@ properties_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verb
     
     swidget = seahorse_widget_new ("applet-preferences", NULL);
     
-    widget = glade_xml_get_widget (swidget->xml, swidget->name);
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, swidget->name));
 
     pixbuf = gtk_widget_render_icon (widget, 
                                      ICON_CLIPBOARD_DEFAULT, 
@@ -690,22 +702,28 @@ properties_cb (BonoboUIComponent *uic, SeahorseApplet *sapplet, const char *verb
     if (!swidget)
         return;
     
-    widget = glade_xml_get_widget (swidget->xml, "show-clipboard-state");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "show-clipboard-state"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
         seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), SHOW_CLIPBOARD_STATE_KEY);
     
-    widget = glade_xml_get_widget (swidget->xml, "display-encrypted-clipboard");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "display-encrypted-clipboard"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
         seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_ENC_KEY);
     
-    widget = glade_xml_get_widget (swidget->xml, "display-decrypted-clipboard");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "display-decrypted-clipboard"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
         seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_DEC_KEY);
         
-    widget = glade_xml_get_widget (swidget->xml, "display-verified-clipboard");
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "display-verified-clipboard"));
     if (widget && GTK_IS_CHECK_BUTTON (widget))
-        seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_VER_KEY);    
-    
+        seahorse_check_button_gconf_attach (GTK_CHECK_BUTTON (widget), DISPLAY_CLIPBOARD_VER_KEY);
+
+    widget = GTK_WIDGET (seahorse_widget_get_widget (swidget, "close"));
+    g_signal_connect (widget, "clicked", G_CALLBACK (close_props), swidget);
+
+    widget = seahorse_widget_get_toplevel (swidget);
+    g_signal_connect (widget, "delete-event", G_CALLBACK (win_destroyed), swidget);
+
     seahorse_widget_show (swidget);
 }
 
@@ -866,13 +884,10 @@ seahorse_applet_init (SeahorseApplet *applet)
     priv->clipboard_contents = SEAHORSE_TEXT_TYPE_NONE;
     
     priv->image = gtk_image_new ();
-    priv->tooltips = gtk_tooltips_new ();
 
     gtk_container_add (GTK_CONTAINER (applet), priv->image);
 
-    g_object_ref (priv->tooltips);
-    gtk_object_sink (GTK_OBJECT (priv->tooltips));
-    gtk_tooltips_set_tip (priv->tooltips, GTK_WIDGET (applet), _("Encryption Applet"), NULL);
+    gtk_widget_set_tooltip_text (GTK_WIDGET (applet), _("Encryption Applet"));
 
     set_atk_name_description (GTK_WIDGET (applet), _("Encryption Applet"), 
                               _("Use PGP/GPG to encrypt/decrypt/sign/verify/import the clipboard."));
@@ -902,7 +917,7 @@ seahorse_applet_change_background (PanelApplet *applet, PanelAppletBackgroundTyp
     gtk_widget_set_style (GTK_WIDGET (applet), NULL);
     rc_style = gtk_rc_style_new ();
     gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-    gtk_rc_style_unref (rc_style);
+    g_object_unref (rc_style);
 
     switch (type){
     case PANEL_NO_BACKGROUND:
@@ -932,10 +947,6 @@ seahorse_applet_finalize (GObject *object)
         if (priv->menu)
             gtk_widget_destroy (priv->menu);
         priv->menu = NULL;
-        
-        if (priv->tooltips)
-            g_object_unref (G_OBJECT (priv->tooltips));
-        priv->tooltips = NULL;
     }
     
     if (G_OBJECT_CLASS (seahorse_applet_parent_class)->finalize)
